@@ -1,7 +1,6 @@
-mod blocktime;
+pub mod clock;
 pub mod instruction;
 
-pub use blocktime::blocktime;
 pub use cronos_program::errors;
 pub use cronos_program::pda;
 pub use cronos_program::state as account;
